/*$Id: mg_main.cc,v 19.13 2001/03/01 09:04:34 al Exp $ -*- C++ -*-
 */
#include "mg_out.h"
/*global*/ int errorcount = 0;
/*--------------------------------------------------------------------------*/
int main(int argc, char** argv)
{
  {if (argc > 2 && strcmp(argv[1],"-h")==0) {
    {for (int i=2; i<argc; ++i) {
      File f(argv[i]);
      make_h_file(f);
    }}
  }else if (argc > 2 && strcmp(argv[1],"-cc")==0) {
    {for (int i=2; i<argc; ++i) {
      File f(argv[i]);
      make_cc_file(f);
    }}
  }else if (argc > 1) {
    {for (int i=1; i<argc; ++i) {
      File f(argv[i]);
      make_h_file(f);
      make_cc_file(f);
    }}
  }else{
    error("no input files");
  }}
  return errorcount;
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
